@@ -1,5 +1,7 @@
 from typing import Final, Iterator, Tuple
 
+import subprocess
+
 from ..decorators import require_bins, run_subprocess
 from ..errors import CliError
 from .params import get_profile
@@ -25,4 +27,15 @@ class AwsOkta:
             for (key, value) in kwargs.items()
             for arg in ("--" + key.replace("_", "-"), value)
         ]
-        yield "aws-okta", "exec", "-r", profile.arn, "--", *args, *options
+
+        base_profile = self.get_base_okta_profile()
+
+        yield "aws-okta", "exec", base_profile, "-r", profile.arn, "--", *args, *options
+
+    def get_base_okta_profile(self) -> str:
+        result = subprocess.run("aws-okta list | sed -n 2p | awk '{print $1}'",
+                capture_output=True, shell=True, text=True)
+        output = result.stdout.rstrip()
+        if result.returncode != 0 or not output:
+            raise CliError("Please run aws-okta login to configure your Okta credentials!")
+        return output
