@@ -1,6 +1,5 @@
-from collections.abc import MutableMapping
 from pathlib import Path
-from typing import Any, cast, Final, Iterator, Literal, TypedDict
+from typing import Any, cast, Final, Iterator, Literal, MutableMapping, TypedDict
 import yaml, os
 
 ConfigKey = Literal["org"]
@@ -13,7 +12,7 @@ class ConfigSchema(TypedDict, total=False):
     org: str
 
 
-class Config(MutableMapping):
+class Config(MutableMapping[ConfigKey, Any]):
     __slots__ = ["path", "config"]
 
     path: Final[Path]
@@ -22,9 +21,13 @@ class Config(MutableMapping):
     def __init__(self) -> None:
         self.path = Path(XDG_CONFIG_HOME) / "sym" / "config.yml"
         self.path.parent.mkdir(parents=True, exist_ok=True)
-        self.config = cast(
-            ConfigSchema, yaml.load(self.path.open("r"), Loader=yaml.FullLoader) or {}
-        )
+        try:
+            config = cast(
+                ConfigSchema, yaml.load(self.path.open("r"), Loader=yaml.FullLoader)
+            )
+        except FileNotFoundError:
+            config = ConfigSchema()
+        self.config = config
 
     def __flush(self) -> None:
         yaml.dump(self.config, self.path.open("w"))
