@@ -24,11 +24,11 @@ PARAMS: Dict[str, OrgParams] = {
             "catfood": Profile(
                 "Catfood", "arn:aws:iam::554582317989:role/ops/SSHAdmin-catamorphic"
             ),
-            "prod-private": Profile(
+            "prod-intuit": Profile(
                 "Prod: Intuit",
                 "arn:aws:iam::527291094460:role/ops/SSHAdmin-production",
             ),
-            "staging-private": Profile(
+            "staging-intuit": Profile(
                 "Staging: Intuit",
                 "arn:aws:iam::527291094460:role/ops/SSHAdmin-staging",
             ),
